import time
from slicer import Slicer, ParsedSettings, ContourGenerator, utils
import gcode2contour as gc


def main(stl_file):
    """
    Instantiate slicer object, slice model
    """
    s = time.time()
    settings = ParsedSettings(slicer_settings_file="configs/slicer.json", printer_settings_file="configs/printer.json")
    sl = Slicer(stl_file, settings, repair_first=True)
    surfs = utils.gen_hemisphere_surfs(sl.model_mesh, settings.resolution, 1, 1)

    print("Created Slicer object, slicing ...")

    # sl.slice(surfs)
    sl.slice_model(surfs)
    sl.gen_shells()

    pl_arr = []
    for i,sli in enumerate(sl.slices):
        pl_arr.append(sl.slice2polylines(sli,i))

    utils.plot_meshes(sl.slices)
    print("done slicing")

    cgen = ContourGenerator(settings, surfs)
    cs = []
    for l in range(len(pl_arr)):
        print("Generating contours for layer", l)
        cs.append(cgen.polylines2contours(pl_arr[l]))

    e = time.time()
    print('\033[92m' + "Slicing and toolpath generation complete in ", e - s, " seconds!" + '\033[0m')
    return sl, cs


if __name__ == "__main__":
    stl_file = "./stl/treefrog_45_cut.stl"
    #single_slice_example(args['file'])
    sl,cs = main(stl_file)
    gc.plot_contours3d(*cs, colors=['black']*len(cs))