"""
Class to parse and hold slicer and printer settings
"""
import json as js

# just put default values here
printer_params = {
    "nozzle diameter": 0.4,
     "extrusion modifier": 1,
     "filament diameter": 1.75,
     "retraction distance": 5,
     "bed centre": [110, 110, 0],
     "z hop": 2,
     }

slicer_params = {
    "perimeter shells": 3,
    "infill pattern": "honeycomb",
    "infill density": 0.2,
    "slice resolution": 110,
    "resample resolution": 0.2,
    "layer height": 0.24,
    "infill threshold": 0.4,
    "auto shell spacing": "True",
    "top bottom shells": 0,
    "brim width": 6,
    }

class ParsedSettings:

    def __init__(self, slicer_settings_file=None, printer_settings_file=None):

        if slicer_settings_file is not None:
            with open(slicer_settings_file, 'r') as s:
                slicer_params = js.load(s)

        if printer_settings_file is not None:
            with open(printer_settings_file, 'r') as p:
                printer_params = js.load(p)
        # if files not provided, use defaults set above

        self.layer_height = slicer_params['layer height']
        self.resolution = slicer_params['slice resolution']
        self.num_shells = slicer_params['perimeter shells']
        self.infill_density = slicer_params['infill density']
        self.brim_width = slicer_params['brim width']
        self.infill_pattern = slicer_params['infill pattern']
        self.infill_threshold = slicer_params['infill threshold']
        self.top_bottom_shells = slicer_params['top bottom shells']
        self.nozzle_diam = printer_params['nozzle diameter']
        self.filament_diam = printer_params['filament diameter']
        self.extrusion_modifier = printer_params['extrusion modifier']
        self.bed_centre = printer_params['bed centre']
        self.retract_dist = printer_params['retraction distance']
        self.auto_spacing = slicer_params['auto shell spacing'].lower() == "true"
        self.extrusion_width = self.nozzle_diam
        self.resample_res = slicer_params['resample resolution']

    def set_extrusion_width(self, extrusion_width):
        """
        Allows modification of the extrusion width property
        """
        self.extrusion_width = extrusion_width